# Domain Network
A package to create a domain network of the URLs mentioned in a dataset of texts. 
In the current version it works for tweets. It may process any kind of text in the future versions.
##Installation
The easiest way to install the domain_network package is to use the following command in a terminal:
``` bash
pip install -i https://test.pypi.org/simple/ domain-network

```
##Usage

##